netapp_ontap.models.maxdata_on_san API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.maxdata_on_san`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MaxdataOnSanSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MaxdataOnSan object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `app_type GET POST`

    Type of the application that is being deployed on the L2.

    Valid choices:

    - mongodb
    - oracle
    - san
  `application_components GET POST PATCH`

    The list of application components to be created.

  `metadata GET POST`

    The metadata field of the maxdata_on_san.

  `new_igroups POST PATCH`

    The list of initiator groups to create.

  `ocsm_url GET`

    The OnCommand System Manager URL for this application.

  `os_type GET POST`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen